@@ -56,8 +56,10 @@
 ##
 # 12  2000 - Incorporate Unconjugate-related stuff
 # 10  2002 - A few fixes in verbs
+#
+# See recent changes in file ChangeLog
 
-$VERSION = '1.09' ;
+$VERSION = '1.11' ;
 
 # Just to make sure which file is loaded
 # BEGIN{ print "SEE THIS ???\n",`pwd` }
@@ -1509,7 +1511,8 @@ moer:
   ivo mi pp modo
 passear:
   passeio passeias passeia passeamos passeiam,
-  ivo passeia  passeie  . . passeiem
+  cpres passeie passeies passeie passeemos passeeis  passeiem
+  ivo passeia  
 incendiar:
   incendeio incendeias incendeia incendiamos incendeiam 
   cpres incedeie incendeies incendeie incendiemos incendeiem 
@@ -1584,6 +1587,8 @@ sair:
   saa saas saa saamos saeis saam
   mdp sara saras sara saramos sareis saram
   cpres saia saias saia saiamos saiais saiam
+  cimp sasse sasses sasse sassemos sasseis sassem
+  cfut sair sares sair sairmos sairdes sarem
   ivo   sai saia saiamos sa saiam
 abrir: pp aberto
 abrir = entreabrir
@@ -1717,7 +1722,14 @@ reaver:
        reaveria reaverias reaveria reaveramos reavereis reaveriam,
        x x x x x, reavido  reavendo
 pedir = despedir medir impedir expedir
-       
+perder:
+  perco ,
+  cpres perca percas perca percais percam
+  ivo perde perca percamos
+crer:
+  creio crs cr . credes crem,
+  cpres creia creias creia creiamos creiais creiam
+  ivo  cr . . crede
 # Double Particpio Passado
 aceitar: pp aceit(o|e|ado)
 afeioar: pp afe(ct|ioad)o
